Fairness statistics
============================

Base statistic definition
----------------------------
.. automodule:: fairret.statistic.base
    :members:
    :undoc-members:
    :show-inheritance:

Linear-fractional statistics
----------------------------

.. automodule:: fairret.statistic.linear_fractional
    :members:
    :undoc-members:
    :show-inheritance: